# package_name

`package_name` is a Python library for ..........

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `package_name`.

```bash
pip install package_name
```

## Usage

```python
import package_name

# returns 'words'
package_name.module_name('word')

# returns 'geese'
package_name.module_name('goose')

# returns 'phenomenon'
package_name.module_name('phenomena')
```

## License
[MIT](https://choosealicense.com/licenses/mit/)